==> humhub-1.15.0-beta.2.tar.gz: humhub-1.15.0-beta.2/protected/humhub/messages/hu/base.php <==
<?php

return [
    '<strong>Confirm</strong> Action' => 'Művelet<strong>megerősítése</strong>',
    '<strong>Latest</strong> updates' => '<strong>Legújabb</strong> frissítések',
    '<strong>Mail</strong> summary' => '<strong>Üzenetek</strong> összesítő',
    'Actions' => 'Műveletek',
    'Add:' => 'Hozzáadás:',
    'Administration' => 'Adminisztráció',
    'All' => 'Minden',
    'Allow' => 'Engedélyezés',
    'Allow content from external source' => 'Külső forrásból származó tartalom engedélyezése',
    'Always allow content from this provider!' => 'Mindig engedélyezze a tartalmat ettől a szolgáltatótól!',
    'An error occurred while handling your last action. (Handler not found).' => 'Egy hiba merült fel a legutóbbi művelet elvégzésekor. (Handler nem található)',
    'An unexpected error occurred while loading the search result.' => 'Váratlan hiba merült fel a keresés eredményeinek betöltése közben.',
    'An unexpected error occurred. If this keeps happening, please contact a site administrator.' => 'Váratlan hiba merült fel. Ha továbbra is hiba lépne fel, keresd az oldal egyik adminisztrátorát.',
    'An unexpected error occurred. Please check whether your file exceeds the allowed upload limit of {maxUploadSize}.' => 'Váratlan hiba történt. Kérjük, ellenőrizze, hogy a fájl meghaladja-e a megengedett {maxUploadSize} feltöltési korlátot.',
    'An unexpected server error occurred. If this keeps happening, please contact a site administrator.' => 'Váratlan szerverhiba történt. Ha továbbra is hiba lépne fel, keresd az oldal egyik adminisztrátorát.',
    'Back' => 'Vissza',
    'Back to dashboard' => 'Vissza az áttekintéshez',
    'Cancel' => 'Mégsem',
    'Choose language:' => 'Válassz nyelvet:',
    'Close' => 'Bezár',
    'Collapse' => 'Összecsukás',
    'Confirm' => 'Rendben',
    'Content Addon source must be instance of HActiveRecordContent or HActiveRecordContentAddon!' => 'A tartalom bővítmény forrásának HActiveRecordContent vagy  HActiveRecordContentAddon példánynak kell lennie!',
    'Copy to clipboard' => 'Másolás vágólapra',
    'Could not find content of addon!' => 'Nem található a bővítmény tartalma!',
    'Could not find requested page.' => 'Nem található a kért oldal!',
    'Default' => 'Alapértelmezett',
    'Delete' => 'Törlés',
    'Deny' => 'Tiltás',
    'Do you really want to perform this action?' => 'Biztos, hogy végrehajtod a műveletet?',
    'Do you want to enable content from \'{urlPrefix}\'?' => 'Engedélyezi a tartalmat a következőről: \'{urlPrefix}\'?',
    'Edit' => 'Szerkesztés',
    'Error' => 'Hiba',
    'Error while running your last action (Invalid request method).' => 'Hiba történt a művelet közben.
(Érvénytelen kérelem)',
    'Error:' => 'Hiba:',
    'Expand' => 'Kinyit',
    'Export' => 'Exportálás',
    'Info:' => 'Információ:',
    'Invalid request method!' => 'Érvénytelen kérelem!',
    'It looks like you may have taken the wrong turn.' => 'Hoppá... Valami hiba történt.',
    'Language' => 'Nyelv:',
    'Loading...' => 'Betöltés...',
    'Login' => 'Bejelentkezés',
    'Logo of {appName}' => '{appName} logója',
    'Logout' => 'Kijelentkezés',
    'Menu' => 'Menü',
    'Module is not enabled on this content container!' => 'A modul nincs engedélyezve a tartalom tárolójában.',
    'My Profile' => 'A profilom',
    'New profile image' => 'Új profilkép',
    'Next' => 'Következő',
    'No error information given.' => 'Nincs hibainformáció.',
    'Oooops...' => 'Hoppá...',
    'Open' => 'Megnyitás',
    'Please type at least 3 characters' => 'Gépelj be legalább 3 karaktert',
    'Please type at least {count} characters' => 'Legalább adj meg {count} karaktert',
    'Powered by {name}' => 'Powered by {name}',
    'Profile dropdown' => 'Profil legördülő menü',
    'Profile picture of {displayName}' => '{displayName} profilképe',
    'Save' => 'Mentés',
    'Saved' => 'Mentve',
    'Search' => 'Keresés',
    'Search...' => 'Keresés...',
    'Select Me' => 'Válassz ki',
    'Settings' => 'Beállítások',
    'Show less' => 'Kevesebb mutatása',
    'Show more' => 'Több mutatása',
    'Some files could not be uploaded:' => 'Néhány fájlt nem sikerült feltölteni:',
    'Stop impersonation' => 'Hagyd abba a személyeskedést!',
    'Text could not be copied to clipboard' => 'A szöveget nem sikerült a vágólapra másolni',
    'Text has been copied to clipboard' => 'A szöveg a vágolapra másolva',
    'The date has to be in the past.' => 'A dátumnak a múltban kell lennie.',
    'The file has been deleted.' => 'A fájlt törölve lett.',
    'The requested resource could not be found.' => 'A kért tartalom nem található.',
    'The space has been archived.' => 'A közösség archiválásra került.',
    'The space has been unarchived.' => 'Közösség archiválása visszavonva.',
    'Time Zone' => 'Időzóna',
    'Toggle comment menu' => 'Hozzászólások menü engedélyezése',
    'Toggle panel menu' => 'Panel menü engedélyezése',
    'Toggle post menu' => 'Bejegyzések menü engedélyezése',
    'Toggle stream entry menu' => 'A hírfolyam menü engedélyezése',
    'Unsaved changes will be lost. Do you want to proceed?' => 'Vannak nem mentett változtatások, valóban el akarod hagyni ezt az oldalt?',
    'Unsubscribe' => 'Leiratkozás',
    'Upload' => 'Feltöltés',
    'Upload file' => 'Fájl feltöltése',
    'You are not allowed to run this action.' => 'Nincs engedélyed, hogy ezt a műveletet végrehajtsd.',
    'verify your upload_max_filesize and post_max_size php settings.' => 'ellenőrizze az upload_max_filesize és a post_max_size php beállításait.',
    '{nFormatted}B' => '{nFormatted}B',
    '{nFormatted}K' => '{nFormatted}K',
    '{nFormatted}M' => '{nFormatted}M',
    '{attribute} has been empty. The system-configured function to fill empty values has returned an invalid value. Please try again or contact your administrator.' => '',
    '{attribute} must be a string (UUID) or null; {type} given.' => '',
    '{attribute} must be an UUID or null. UUID has the format "{{XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX}}", where X = [a-fA-F0-9] and both curly brackets and delimiting dashes are optional.' => '',
];

==> humhub-1.16.0-beta.2.tar.gz: humhub-1.16.0-beta.2/protected/humhub/messages/hu/base.php <==
<?php

return [
    '<strong>Confirm</strong> Action' => 'Művelet<strong>megerősítése</strong>',
    '<strong>Latest</strong> updates' => '<strong>Legújabb</strong> frissítések',
    '<strong>Mail</strong> summary' => '<strong>Üzenetek</strong> összesítő',
    'Actions' => 'Műveletek',
    'Add:' => 'Hozzáadás:',
    'Administration' => 'Adminisztráció',
    'All' => 'Minden',
    'Allow' => 'Engedélyezés',
    'Allow content from external source' => 'Külső forrásból származó tartalom engedélyezése',
    'Always allow content from this provider!' => 'Mindig engedélyezze a tartalmat ettől a szolgáltatótól!',
    'An error occurred while handling your last action. (Handler not found).' => 'Egy hiba merült fel a legutóbbi művelet elvégzésekor. (Handler nem található)',
    'An unexpected error occurred while loading the search result.' => 'Váratlan hiba merült fel a keresés eredményeinek betöltése közben.',
    'An unexpected error occurred. If this keeps happening, please contact a site administrator.' => 'Váratlan hiba merült fel. Ha továbbra is hiba lépne fel, keresd az oldal egyik adminisztrátorát.',
    'An unexpected error occurred. Please check whether your file exceeds the allowed upload limit of {maxUploadSize}.' => 'Váratlan hiba történt. Kérjük, ellenőrizze, hogy a fájl meghaladja-e a megengedett {maxUploadSize} feltöltési korlátot.',
    'An unexpected server error occurred. If this keeps happening, please contact a site administrator.' => 'Váratlan szerverhiba történt. Ha továbbra is hiba lépne fel, keresd az oldal egyik adminisztrátorát.',
    'Back' => 'Vissza',
    'Back to dashboard' => 'Vissza az áttekintéshez',
    'Cancel' => 'Mégsem',
    'Choose language:' => 'Válassz nyelvet:',
    'Close' => 'Bezár',
    'Collapse' => 'Összecsukás',
    'Confirm' => 'Rendben',
    'Content Addon source must be instance of HActiveRecordContent or HActiveRecordContentAddon!' => 'A tartalom bővítmény forrásának HActiveRecordContent vagy  HActiveRecordContentAddon példánynak kell lennie!',
    'Copy to clipboard' => 'Másolás vágólapra',
    'Could not find content of addon!' => 'Nem található a bővítmény tartalma!',
    'Could not find requested page.' => 'Nem található a kért oldal!',
    'Default' => 'Alapértelmezett',
    'Delete' => 'Törlés',
    'Deny' => 'Tiltás',
    'Do you really want to perform this action?' => 'Biztos, hogy végrehajtod a műveletet?',
    'Do you want to enable content from \'{urlPrefix}\'?' => 'Engedélyezi a tartalmat a következőről: \'{urlPrefix}\'?',
    'Edit' => 'Szerkesztés',
    'Error' => 'Hiba',
    'Error while running your last action (Invalid request method).' => 'Hiba történt a művelet közben.
(Érvénytelen kérelem)',
    'Error:' => 'Hiba:',
    'Expand' => 'Kinyit',
    'Export' => 'Exportálás',
    'Info:' => 'Információ:',
    'Invalid request method!' => 'Érvénytelen kérelem!',
    'It looks like you may have taken the wrong turn.' => 'Hoppá... Valami hiba történt.',
    'Language' => 'Nyelv:',
    'Loading...' => 'Betöltés...',
    'Login' => 'Bejelentkezés',
    'Logo of {appName}' => '{appName} logója',
    'Logout' => 'Kijelentkezés',
    'Menu' => 'Menü',
    'Module is not enabled on this content container!' => 'A modul nincs engedélyezve a tartalom tárolójában.',
    'My Profile' => 'A profilom',
    'New profile image' => 'Új profilkép',
    'Next' => 'Következő',
    'No error information given.' => 'Nincs hibainformáció.',
    'Oooops...' => 'Hoppá...',
    'Open' => 'Megnyitás',
    'Please type at least 3 characters' => 'Gépelj be legalább 3 karaktert',
    'Please type at least {count} characters' => 'Legalább adj meg {count} karaktert',
    'Powered by {name}' => 'Powered by {name}',
    'Profile dropdown' => 'Profil legördülő menü',
    'Profile picture of {displayName}' => '{displayName} profilképe',
    'Save' => 'Mentés',
    'Saved' => 'Mentve',
    'Search' => 'Keresés',
    'Search...' => 'Keresés...',
    'Select Me' => 'Válassz ki',
    'Settings' => 'Beállítások',
    'Show less' => 'Kevesebb mutatása',
    'Show more' => 'Több mutatása',
    'Some files could not be uploaded:' => 'Néhány fájlt nem sikerült feltölteni:',
    'Stop impersonation' => 'Hagyd abba a személyeskedést!',
    'Text could not be copied to clipboard' => 'A szöveget nem sikerült a vágólapra másolni',
    'Text has been copied to clipboard' => 'A szöveg a vágolapra másolva',
    'The date has to be in the past.' => 'A dátumnak a múltban kell lennie.',
    'The file has been deleted.' => 'A fájlt törölve lett.',
    'The requested resource could not be found.' => 'A kért tartalom nem található.',
    'The space has been archived.' => 'A közösség archiválásra került.',
    'The space has been unarchived.' => 'Közösség archiválása visszavonva.',
    'Time Zone' => 'Időzóna',
    'Toggle comment menu' => 'Hozzászólások menü engedélyezése',
    'Toggle panel menu' => 'Panel menü engedélyezése',
    'Toggle post menu' => 'Bejegyzések menü engedélyezése',
    'Toggle stream entry menu' => 'A hírfolyam menü engedélyezése',
    'Unsaved changes will be lost. Do you want to proceed?' => 'Vannak nem mentett változtatások, valóban el akarod hagyni ezt az oldalt?',
    'Unsubscribe' => 'Leiratkozás',
    'Upload' => 'Feltöltés',
    'Upload file' => 'Fájl feltöltése',
    'You are not allowed to run this action.' => 'Nincs engedélyed, hogy ezt a műveletet végrehajtsd.',
    'verify your upload_max_filesize and post_max_size php settings.' => 'ellenőrizze az upload_max_filesize és a post_max_size php beállításait.',
    '{attribute} has been empty. The system-configured function to fill empty values has returned an invalid value. Please try again or contact your administrator.' => 'Az {attribute} üres. A rendszer által beállított üres értékek kitöltésére szolgáló függvény érvénytelen értéket adott vissza. Kérjük, próbálja újra, vagy forduljon a rendszergazdához.',
    '{attribute} must be a string (UUID) or null; {type} given.' => 'Az {attribute} karakterláncnak (UUID) vagy nullának kell lennie; {type} adott.',
    '{attribute} must be an UUID or null. UUID has the format "{{XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX}}", where X = [a-fA-F0-9] and both curly brackets and delimiting dashes are optional.' => 'Az {attribute} UUID-nek vagy nullának kell lennie. Az UUID formátuma „{{XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX}}”, ahol X = [a-fA-F0-9], és a zárójelek és az elválasztó kötőjelek nem kötelezőek.',
    '{nFormatted}B' => '{nFormatted}B',
    '{nFormatted}K' => '{nFormatted}K',
    '{nFormatted}M' => '{nFormatted}M',
    'No results' => '',
    'Show all results' => '',
];
